@@ -43,6 +43,10 @@ has '_select_sound' => (is => 'rw', isa => 'SDL::Mixer::MixChunk' );
 sub BUILD {
     my $self = shift;
 
+	 unless ( SDL::Config->has('SDL_ttf') ) {
+        Carp::cluck("SDL_ttf support has not been compiled");
+    }
+
     $self->_build_font;
     $self->_build_sound;
 }
@@ -50,7 +54,10 @@ sub BUILD {
 sub _build_font {
     my $self = shift;
 
-    SDL::TTF::init;
+  	unless ( SDL::TTF::was_init() )
+    {
+       Carp::cluck ("Cannot init TTF: " . SDL::get_error() ) unless SDL::TTF::init() == 0;
+	}
     $self->_font( SDL::TTF::open_font( $self->font, $self->font_size ) );
 
     Carp::croak 'Error opening font: ' . SDL::get_error
